==> jc-1.4.0.tar.gz: java/security/cert/CertificateExpiredException.h <==
// public class java.security.cert.CertificateExpiredException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 692089051f4c8d0b java_security_GeneralSecurityException
// @dep_class ebfb598dd9fa8080 java_security_cert_CertificateException
// @dep_class 9ae23338b9abfc6b java_security_cert_CertificateExpiredException

// header file dependencies
// @dep_header java_security_cert_CertificateException

#include "java/security/cert/CertificateException.h"

#ifndef _JC_java_security_cert_CertificateExpiredException_H_
#define _JC_java_security_cert_CertificateExpiredException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_security_cert_CertificateExpiredException$sub_refs	_jc_java_security_cert_CertificateExpiredException$sub_refs;
typedef struct _jc_java_security_cert_CertificateExpiredException$sub_nonrefs	_jc_java_security_cert_CertificateExpiredException$sub_nonrefs;
typedef struct _jc_java_security_cert_CertificateExpiredException$refs	_jc_java_security_cert_CertificateExpiredException$refs;
typedef struct _jc_java_security_cert_CertificateExpiredException$nonrefs	_jc_java_security_cert_CertificateExpiredException$nonrefs;
typedef struct _jc_java_security_cert_CertificateExpiredException$object	_jc_java_security_cert_CertificateExpiredException$object;

typedef struct _jc_java_security_cert_CertificateExpiredException$fields_struct	_jc_java_security_cert_CertificateExpiredException$fields_struct;
typedef const struct _jc_java_security_cert_CertificateExpiredException$vmethods	_jc_java_security_cert_CertificateExpiredException$vmethods;
typedef const struct _jc_java_security_cert_CertificateExpiredException$vtable	_jc_java_security_cert_CertificateExpiredException$vtable;
typedef const struct _jc_java_security_cert_CertificateExpiredException$vtype	_jc_java_security_cert_CertificateExpiredException$vtype;

// Class fields structure
struct _jc_java_security_cert_CertificateExpiredException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_security_cert_CertificateExpiredException$fields_struct _jc_java_security_cert_CertificateExpiredException$class_fields;

// Constructors
extern void _jc_java_security_cert_CertificateExpiredException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_security_cert_CertificateExpiredException$object *);
extern void _jc_java_security_cert_CertificateExpiredException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_security_cert_CertificateExpiredException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_java_security_cert_CertificateExpiredException$vmethods {
};

// Vtable
struct _jc_java_security_cert_CertificateExpiredException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_security_GeneralSecurityException$vmethods	java_security_GeneralSecurityException;
	_jc_java_security_cert_CertificateException$vmethods	java_security_cert_CertificateException;
	_jc_java_security_cert_CertificateExpiredException$vmethods	java_security_cert_CertificateExpiredException;
};

// Vtype
struct _jc_java_security_cert_CertificateExpiredException$vtype {
	_jc_type			type;
	_jc_java_security_cert_CertificateExpiredException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_cert_CertificateExpiredException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_security_cert_CertificateExpiredException$refs {
    _jc_java_security_cert_CertificateExpiredException$sub_refs	java_security_cert_CertificateExpiredException;
    _jc_java_security_cert_CertificateException$sub_refs	java_security_cert_CertificateException;
    _jc_java_security_GeneralSecurityException$sub_refs	java_security_GeneralSecurityException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_cert_CertificateExpiredException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_cert_CertificateExpiredException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_security_GeneralSecurityException$sub_nonrefs	java_security_GeneralSecurityException;
    _jc_java_security_cert_CertificateException$sub_nonrefs	java_security_cert_CertificateException;
    _jc_java_security_cert_CertificateExpiredException$sub_nonrefs	java_security_cert_CertificateExpiredException;
};

// Object instance structure
struct _jc_java_security_cert_CertificateExpiredException$object {
	_jc_java_security_cert_CertificateExpiredException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_cert_CertificateExpiredException$vtype	*vtype;
	_jc_java_security_cert_CertificateExpiredException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_cert_CertificateExpiredException$vtype _jc_java_security_cert_CertificateExpiredException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_cert_CertificateExpiredException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_cert_CertificateExpiredException$class_object;

#endif	/* _JC_java_security_cert_CertificateExpiredException_H_ */

==> jc-1.4.6.tar.gz: java/security/cert/CertificateExpiredException.h <==
// public class java.security.cert.CertificateExpiredException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 692089051f4c8d0b java_security_GeneralSecurityException
// @dep_class ebfb598dd9fa8080 java_security_cert_CertificateException
// @dep_class 9ae23338b9abfc6b java_security_cert_CertificateExpiredException

// header file dependencies
// @dep_header java_security_cert_CertificateException

#include "java/security/cert/CertificateException.h"

#ifndef _JC_java_security_cert_CertificateExpiredException_H_
#define _JC_java_security_cert_CertificateExpiredException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_security_cert_CertificateExpiredException$sub_refs	_jc_java_security_cert_CertificateExpiredException$sub_refs;
typedef struct _jc_java_security_cert_CertificateExpiredException$sub_nonrefs	_jc_java_security_cert_CertificateExpiredException$sub_nonrefs;
typedef struct _jc_java_security_cert_CertificateExpiredException$refs	_jc_java_security_cert_CertificateExpiredException$refs;
typedef struct _jc_java_security_cert_CertificateExpiredException$nonrefs	_jc_java_security_cert_CertificateExpiredException$nonrefs;
typedef struct _jc_java_security_cert_CertificateExpiredException$object	_jc_java_security_cert_CertificateExpiredException$object;

typedef struct _jc_java_security_cert_CertificateExpiredException$fields_struct	_jc_java_security_cert_CertificateExpiredException$fields_struct;
typedef const struct _jc_java_security_cert_CertificateExpiredException$vmethods	_jc_java_security_cert_CertificateExpiredException$vmethods;
typedef const struct _jc_java_security_cert_CertificateExpiredException$vtable	_jc_java_security_cert_CertificateExpiredException$vtable;
typedef const struct _jc_java_security_cert_CertificateExpiredException$vtype	_jc_java_security_cert_CertificateExpiredException$vtype;

// Class fields structure
struct _jc_java_security_cert_CertificateExpiredException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_security_cert_CertificateExpiredException$fields_struct _jc_java_security_cert_CertificateExpiredException$class_fields;

// Constructors
extern void _jc_java_security_cert_CertificateExpiredException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_security_cert_CertificateExpiredException$object *) _JC_JCNI_ATTR;
extern void _jc_java_security_cert_CertificateExpiredException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_security_cert_CertificateExpiredException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_security_cert_CertificateExpiredException$vmethods {
};

// Vtable
struct _jc_java_security_cert_CertificateExpiredException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_security_GeneralSecurityException$vmethods	java_security_GeneralSecurityException;
	_jc_java_security_cert_CertificateException$vmethods	java_security_cert_CertificateException;
	_jc_java_security_cert_CertificateExpiredException$vmethods	java_security_cert_CertificateExpiredException;
};

// Vtype
struct _jc_java_security_cert_CertificateExpiredException$vtype {
	_jc_type			type;
	_jc_java_security_cert_CertificateExpiredException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_cert_CertificateExpiredException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_security_cert_CertificateExpiredException$refs {
    _jc_java_security_cert_CertificateExpiredException$sub_refs	java_security_cert_CertificateExpiredException;
    _jc_java_security_cert_CertificateException$sub_refs	java_security_cert_CertificateException;
    _jc_java_security_GeneralSecurityException$sub_refs	java_security_GeneralSecurityException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_cert_CertificateExpiredException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_cert_CertificateExpiredException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_security_GeneralSecurityException$sub_nonrefs	java_security_GeneralSecurityException;
    _jc_java_security_cert_CertificateException$sub_nonrefs	java_security_cert_CertificateException;
    _jc_java_security_cert_CertificateExpiredException$sub_nonrefs	java_security_cert_CertificateExpiredException;
};

// Object instance structure
struct _jc_java_security_cert_CertificateExpiredException$object {
	_jc_java_security_cert_CertificateExpiredException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_cert_CertificateExpiredException$vtype	*vtype;
	_jc_java_security_cert_CertificateExpiredException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_cert_CertificateExpiredException$vtype _jc_java_security_cert_CertificateExpiredException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_cert_CertificateExpiredException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_cert_CertificateExpiredException$class_object;

#endif	/* _JC_java_security_cert_CertificateExpiredException_H_ */
